<?php
// © Microsoft Corporation. All rights reserved.

namespace microsoft_start\routes;

use microsoft_start\services\MSPostConvertService;
use microsoft_start\infrastructure\ApiController;
use microsoft_start\services\MSNClient;
use microsoft_start\services\MSPostMetaService;

class postApi extends ApiController
{
    function register_routes()
    {
        register_rest_route("microsoft/v1", "/msn-article-retrieval", [
            "methods" => "POST",
            'permission_callback' => function () {
                return current_user_can('edit_posts');
            },
            'callback' => function ($data) {
                $parameters = $data->get_json_params();
                $article_id_list = $parameters['articles'];

                $publishStatus = array_map(function ($item) {
                    if (isset($item->id)) {
                        $post = MSPostMetaService::get_post_by_msn_id($item->id);
                        return [
                            'id' => $item->id,
                            'msn_status' => $item->status,
                            'wp_status' => $post->post_status,
                            'validation' => array_map(function ($failure) {
                                return $failure->failureReason;
                            }, $item->failedTargets ?? [])
                        ];
                    } else {
                        return [
                            'id' => null,
                            'msn_status' => null,
                            'wp_status' => null,
                            'validation' => []
                        ];
                    }
                    
                }, MSNClient::get_article_publish_status($article_id_list));
                return $publishStatus;
            }
        ]);

        register_rest_route("microsoft/v1", "/msn-article-detail/(?P<msnId>[A-Za-z0-9_]+)", [
            "methods" => "GET",
            'permission_callback' => function () {
                return current_user_can('edit_posts');
            },
            'callback' => function ($data) {
                $msn_id = $data['msnId'];
                $post = MSPostMetaService::get_post_by_msn_id($msn_id);
                if ($post) {
                    return array_merge(
                        ["id" => $msn_id],
                        MSPostConvertService::get_post_detail($post),
                        MSPostMetaService::get_all_ms_post_meta($post->ID)
                    );
                } else {
                    return null;
                }
                
            }
        ]);
        register_rest_route("microsoft/v1", "/post-detail/(?P<postId>[0-9_]+)", [
            "methods" => "GET",
            'permission_callback' => function () {
                return current_user_can('edit_posts');
            },
            'callback' => function ($data) {
                $post_id = $data['postId'];
                $post = get_post($post_id);
                return array_merge(
                    ["id" => $post->ID],
                    MSPostConvertService::get_post_detail($post),
                    MSPostMetaService::get_default_ms_post_meta()
                );
            }
        ]);
        register_rest_route("microsoft/v1", "/msn-id/(?P<postId>[0-9_]+)", [
            "methods" => "GET",
            'permission_callback' => function () {
                return current_user_can('edit_posts');
            },
            'callback' => function ($data) {
                $post_id = $data['postId'];
                return get_post_meta($post_id, 'msn_id', true);
            }
        ]);
    }
}
