<?php
// © Microsoft Corporation. All rights reserved.

namespace microsoft_start\services;

class MSPostMetaService
{
    private static $ms_post_meta_keys = [
        "MSN_Publish_Option",
        "MSN_Categories",
        "MSN_Is_Local_News",
        "MSN_Location",
        "MSN_Has_Custom_Author",
        "MSN_Custom_Author",
        "MSN_Has_Custom_Canonical_Url",
        "MSN_Custom_Canonical_Url"
    ];

    public static function set_default_ms_post_meta($postID)
    {
        static::update_meta_data_by_id($postID, static::get_default_ms_post_meta(true));
    }

    public static function update_meta_data_from_request($postID)
    {
        // update post meta according to the payload in POST request
        $post_request_data = json_decode(file_get_contents('php://input'), true);
        $meta_from_request = $post_request_data['meta'] ?? null;
        if (is_array($meta_from_request)) {
            static::update_meta_data_by_id($postID, $meta_from_request);
        }
    }

    public static function get_post_by_msn_id($msn_id)
    {
        global $wpdb;
        $meta_row = $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->postmeta WHERE meta_key='msn_id' AND meta_value='$msn_id'"));
        $post_id = $meta_row->post_id;
        return get_post($post_id);
    }

    public static function get_all_ms_post_meta($postID)
    {
        // Get the meta values
        $all_meta = get_post_meta($postID);
        // Filter out by MS related keys
        $filtered_meta = array_intersect_key($all_meta, array_flip(static::$ms_post_meta_keys));
        // Convert them to singles and return them
        return array_map(function ($n) {
            return $n[0];
        }, $filtered_meta);
    }

    public static function get_default_ms_post_meta($shouldSlashLocation = false)
    {
        return [
            "MSN_Publish_Option" => Options::get_enable() ? "1" : "0",
            "MSN_Categories" => Options::get_category(),
            "MSN_Is_Local_News" => Options::get_editor_is_local_news(),
            // using wp_slash here to prevent wrong format of locaiton being passed to data-memorizedLocation field of the location selector of newsPanelBody
            "MSN_Location" => $shouldSlashLocation ? wp_slash(Options::get_editor_location()) : Options::get_editor_location(),
            "MSN_Has_Custom_Author" => "0",
            "MSN_Custom_Author" => "",
            "MSN_Has_Custom_Canonical_Url" => "0",
            "MSN_Custom_Canonical_Url" => ""
        ];
    }
    
    private static function update_meta_data_by_id($postID, $meta)
    {
        foreach(static::$ms_post_meta_keys as $key)
        {
            update_post_meta($postID, $key, $meta[$key]);
        }
    }
}